https://github.com/EttusResearch/uhd/pull/652

From 48a05bf621a056af7764437760ad5d64684ce7d2 Mon Sep 17 00:00:00 2001
From: Sam James <sam@gentoo.org>
Date: Tue, 3 Jan 2023 23:04:52 +0000
Subject: [PATCH] Fix build with GCC 13 (add missing <cstdint> include)

GCC 13 (as usual for new compiler releases) shuffles around some
internal includes and so <cstdint> is no longer transitively included.

Explicitly include <cstdint> for uint8_t.

```
/var/tmp/portage/net-wireless/uhd-4.3.0.0/work/uhd-4.3.0.0/include/uhd/rfnoc/defaults.hpp:43:14: error: 'uint32_t' does not name a type
   43 | static const uint32_t DEFAULT_NOC_ID  = 0xFFFFFFFF;
      |              ^~~~~~~~
/var/tmp/portage/net-wireless/uhd-4.3.0.0/work/uhd-4.3.0.0/include/uhd/rfnoc/defaults.hpp:1:1: note: 'uint32_t' is defined in header '<cstdint>'; did you forget to '#include <cstdint>'?
  +++ |+#include <cstdint>
    1 | //
```

Signed-off-by: Sam James <sam@gentoo.org>
--- a/include/uhd/cal/database.hpp
+++ b/include/uhd/cal/database.hpp
@@ -8,6 +8,7 @@
 
 #include <uhd/config.hpp>
 #include <stddef.h>
+#include <cstdint>
 #include <string>
 #include <vector>
 #include <functional>
--- a/include/uhd/rfnoc/defaults.hpp
+++ b/include/uhd/rfnoc/defaults.hpp
@@ -8,6 +8,7 @@
 
 #pragma once
 
+#include <cstdint>
 #include <string>
 
 namespace uhd { namespace rfnoc {
--- a/include/uhd/types/eeprom.hpp
+++ b/include/uhd/types/eeprom.hpp
@@ -6,6 +6,7 @@
 
 #pragma once
 
+#include <cstdint>
 #include <map>
 #include <string>
 #include <vector>
--- a/include/uhd/usrp/zbx_tune_map_item.hpp
+++ b/include/uhd/usrp/zbx_tune_map_item.hpp
@@ -6,6 +6,7 @@
 
 #pragma once
 #include <uhd/config.hpp>
+#include <cstdint>
 #include <cstring>
 #include <string>
 #include <vector>
--- a/lib/usrp/dboard/magnesium/magnesium_constants.hpp
+++ b/lib/usrp/dboard/magnesium/magnesium_constants.hpp
@@ -9,6 +9,7 @@
 
 #include <uhd/types/ranges.hpp>
 #include <cstddef>
+#include <cstdint>
 #include <string>
 #include <vector>
 
--- a/lib/usrp/dboard/rhodium/rhodium_constants.hpp
+++ b/lib/usrp/dboard/rhodium/rhodium_constants.hpp
@@ -9,6 +9,7 @@
 
 #include <array>
 #include <cstddef>
+#include <cstdint>
 #include <string>
 #include <vector>
 
--- a/lib/utils/serial_number.cpp
+++ b/lib/utils/serial_number.cpp
@@ -5,6 +5,7 @@
 //
 
 #include <uhdlib/utils/serial_number.hpp>
+#include <cstdint>
 #include <stdexcept>
 #include <string>
 
-- 
2.39.0

